{
    "$graph": [
        {
            "class": "Workflow",
            "label": "exome alignment with qc",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#sequence_data.yml/sequence_data",
                            "label": "sequence data with readgroup information",
                            "fields": [
                                {
                                    "type": "string",
                                    "name": "#sequence_data.yml/sequence_data/readgroup"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/bam",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/bam/bam"
                                                }
                                            ]
                                        },
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/fastqs",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq1"
                                                },
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq2"
                                                }
                                            ]
                                        }
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/sequence"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bait_intervals"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/final_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/qc_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/qc_minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#main/sequence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/summary_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/target_intervals"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_to_bqsr.cwl",
                    "in": [
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/alignment/bqsr_intervals"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/alignment/dbsnp_vcf"
                        },
                        {
                            "source": "#main/final_name",
                            "id": "#main/alignment/final_name"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/alignment/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/alignment/mills"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment/reference"
                        },
                        {
                            "source": "#main/sequence",
                            "id": "#main/alignment/unaligned"
                        }
                    ],
                    "out": [
                        "#main/alignment/final_bam",
                        "#main/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#main/alignment"
                },
                {
                    "run": "#qc_exome.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/qc/bait_intervals"
                        },
                        {
                            "source": "#main/alignment/final_bam",
                            "id": "#main/qc/bam"
                        },
                        {
                            "source": "#main/qc_minimum_base_quality",
                            "id": "#main/qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/qc_minimum_mapping_quality",
                            "id": "#main/qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/qc/reference"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "id": "#main/qc/summary_intervals"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/qc/insert_size_metrics",
                        "#main/qc/insert_size_histogram",
                        "#main/qc/alignment_summary_metrics",
                        "#main/qc/hs_metrics",
                        "#main/qc/per_target_coverage_metrics",
                        "#main/qc/per_target_hs_metrics",
                        "#main/qc/per_base_coverage_metrics",
                        "#main/qc/per_base_hs_metrics",
                        "#main/qc/summary_hs_metrics",
                        "#main/qc/flagstats",
                        "#main/qc/verify_bam_id_metrics",
                        "#main/qc/verify_bam_id_depth"
                    ],
                    "id": "#main/qc"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment/final_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/hs_metrics",
                    "id": "#main/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment/mark_duplicates_metrics_file",
                    "id": "#main/mark_duplicates_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_base_hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_target_hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/summary_hs_metrics",
                    "id": "#main/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "HS Metrics workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#hs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_target_intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#hs_metrics.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/summary_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/summary_hs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "base-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "target-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "summary-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_summary_hs_metrics"
                }
            ],
            "id": "#hs_metrics.cwl"
        },
        {
            "class": "Workflow",
            "label": "Exome QC workflow",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#qc_exome.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#qc_exome.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_exome.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_exome.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#qc_exome.cwl/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "default": "ALL_READS",
                    "id": "#qc_exome.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#qc_exome.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/summary_intervals"
                },
                {
                    "type": "File",
                    "id": "#qc_exome.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#qc_exome.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/samtools_flagstat/flagstats",
                    "id": "#qc_exome.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_roi_hs_metrics/hs_metrics",
                    "id": "#qc_exome.cwl/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#qc_exome.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#qc_exome.cwl/insert_size_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_coverage_metrics",
                    "id": "#qc_exome.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_hs_metrics",
                    "id": "#qc_exome.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_coverage_metrics",
                    "id": "#qc_exome.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_hs_metrics",
                    "id": "#qc_exome.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/summary_hs_metrics",
                    "id": "#qc_exome.cwl/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#qc_exome.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#qc_exome.cwl/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/picard_metric_accumulation_level",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_base_quality",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_mapping_quality",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/per_base_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/per_target_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/summary_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/summary_intervals"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_coverage_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_hs_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_coverage_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_hs_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/summary_hs_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_detailed_hs_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/picard_metric_accumulation_level",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#qc_exome.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#qc_exome.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bait_intervals",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_base_quality",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_mapping_quality",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "roi",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/target_intervals",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_roi_hs_metrics/hs_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_roi_hs_metrics"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/samtools_flagstat/bam"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#qc_exome.cwl/samtools_flagstat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/target_intervals",
                            "id": "#qc_exome.cwl/select_variants/interval_list"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/select_variants/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/omni_vcf",
                            "id": "#qc_exome.cwl/select_variants/vcf"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/select_variants/filtered_vcf"
                    ],
                    "id": "#qc_exome.cwl/select_variants"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/select_variants/filtered_vcf",
                            "id": "#qc_exome.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#qc_exome.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#qc_exome.cwl/verify_bam_id"
                }
            ],
            "id": "#qc_exome.cwl"
        },
        {
            "class": "Workflow",
            "label": "adapter for sequence_align_and_tag",
            "doc": "Some workflow engines won't stage files in our nested structure, so parse it out here",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag_adapter.cwl/reference"
                },
                {
                    "type": "#sequence_data.yml/sequence_data",
                    "doc": "the unaligned sequence data with readgroup information",
                    "id": "#sequence_align_and_tag_adapter.cwl/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam",
                    "id": "#sequence_align_and_tag_adapter.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('bam')? self.sequence.bam : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq1')? self.sequence.fastq1 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq1"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq2')? self.sequence.fastq2 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq2"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.readgroup)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/reference",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag"
                }
            ],
            "id": "#sequence_align_and_tag_adapter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Raw sequence data to BQSR",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#sequence_to_bqsr.cwl/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#sequence_to_bqsr.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "default": "final",
                    "id": "#sequence_to_bqsr.cwl/final_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#sequence_to_bqsr.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#sequence_to_bqsr.cwl/mills"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#sequence_to_bqsr.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#sequence_to_bqsr.cwl/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_to_bqsr.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#sequence_to_bqsr.cwl/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file",
                    "id": "#sequence_to_bqsr.cwl/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#sequence_to_bqsr.cwl/align/unaligned"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#sequence_align_and_tag_adapter.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/align/reference"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/unaligned",
                            "id": "#sequence_to_bqsr.cwl/align/unaligned"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/align/aligned_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/bam"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/bqsr/bqsr_table",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/final_name",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/output_name"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/apply_bqsr"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/bqsr/bam"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/bqsr_intervals",
                            "id": "#sequence_to_bqsr.cwl/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#sequence_to_bqsr.cwl/dbsnp_vcf",
                                "#sequence_to_bqsr.cwl/mills",
                                "#sequence_to_bqsr.cwl/known_indels"
                            ],
                            "id": "#sequence_to_bqsr.cwl/bqsr/known_sites"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/bqsr/bqsr_table"
                    ],
                    "id": "#sequence_to_bqsr.cwl/bqsr"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_bam",
                            "id": "#sequence_to_bqsr.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/index_bam"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/name_sort/name_sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                        "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge_bams_samtools.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/align/aligned_bam",
                            "id": "#sequence_to_bqsr.cwl/merge/bams"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/final_name",
                            "id": "#sequence_to_bqsr.cwl/merge/name"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/merge/merged_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/merge/merged_bam",
                            "id": "#sequence_to_bqsr.cwl/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/name_sort/name_sorted_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/name_sort"
                }
            ],
            "id": "#sequence_to_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_name).bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#apply_bqsr.cwl/output_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx48g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 52000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_hs_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mark duplicates and Sort",
            "baseCommand": [
                "/bin/bash",
                "markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mark_duplicates-cwl:1.0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "markduplicates_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\ndeclare MD_BARCODE_TAG\nif [ ! -z \"$6\" ]; then\n  MD_BARCODE_TAG=\"BARCODE_TAG=$6\"\n/usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT \"$MD_BARCODE_TAG\" | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nelse\n  /usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "queryname",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mark_duplicates_and_sort.cwl/input_sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "MarkedSorted.bam",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mark_duplicates_and_sort.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Samtools: merge",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "arguments": [
                "$(inputs.name).merged.bam",
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams_samtools.cwl/bams"
                },
                {
                    "type": "string",
                    "id": "#merge_bams_samtools.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name).merged.bam"
                    },
                    "id": "#merge_bams_samtools.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams_samtools.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "22G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(inputs.bam.nameroot).NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 26000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/sambamba-cwl:0.6.4"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "stdout": "$(inputs.bam.basename).flagstat",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_flagstat.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename).flagstat"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample_name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-selectType",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "doc": "Due to workflow runner limitations, use sequence_align_and_tag_adapter.cwl subworkflow to call this",
            "baseCommand": [
                "/bin/bash",
                "sequence_alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/alignment_helper-cwl:1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "sequence_alignment_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\nset -o nounset\n\nwhile getopts \"b:?1:?2:?g:r:n:\" opt; do\n    case \"$opt\" in\n        b)\n            MODE=bam\n            BAM=\"$OPTARG\"\n            ;;\n        1)\n            MODE=fastq\n            FASTQ1=\"$OPTARG\"\n            ;;\n        2)  \n            MODE=fastq\n            FASTQ2=\"$OPTARG\"\n            ;;\n        g)\n            READGROUP=\"$OPTARG\"\n            ;;\n        r)\n            REFERENCE=\"$OPTARG\"\n            ;;\n        n)\n            NTHREADS=\"$OPTARG\"\n            ;;\n    esac\ndone\n\nif [[ \"$MODE\" == 'fastq' ]]; then\n    /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -R \"$READGROUP\" \"$REFERENCE\" \"$FASTQ1\" \"$FASTQ2\" | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\nfi\nif [[ \"$MODE\" == 'bam' ]]; then\n    /usr/bin/java -Xmx4g -jar /opt/picard/picard.jar SamToFastq I=\"$BAM\" INTERLEAVE=true INCLUDE_NON_PF_READS=true FASTQ=/dev/stdout | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 5,
                    "prefix": "-n"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#sequence_align_and_tag.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#sequence_align_and_tag.cwl/readgroup"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-r"
                    },
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sequence_align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#sequence_align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/verify_bam_id-cwl:1.1.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
